Plyvel — Plyvel 1.0.2 documentation

# Plyvel

Plyvel is a fast and feature-rich Python interface to LevelDB.

Plyvel’s key features are:

- Rich feature set

  Plyvel wraps most of the LevelDB C++ API and adds some features of its own. In addition to basic features like getting, putting and deleting data, Plyvel allows you to use write batches, database snapshots, very flexible iterators, prefixed databases, bloom filters, custom cache sizes, custom comparators, and other goodness LevelDB has to offer.

- Friendly Pythonic API

  Plyvel has a friendly and well-designed API that uses Python idioms like iterators and context managers (`with` blocks), without sacrificing the power or performance of the underlying LevelDB C++ API.

- High performance

  Plyvel executes all performance-critical code at C speed (using Cython), which means Plyvel is a good fit for high performance applications.

- Extensive documentation

  Plyvel comes with extensive documentation, including a user guide and API reference material.

- Python 2 and Python 3 compatibility

  Plyvel works with both Python 2 and Python 3, without any API differences.

You should know that Plyvel is a hobby project, written and maintained by me, Wouter Bolsterlee, in my spare time. Please consider making a small donation to let me know you appreciate my work. Thanks!

Documentation contents

- Installation guide
  - Build and install Plyvel
  - Verify that it works
- User guide
  - Getting started
  - Basic operations
  - Important note about byte strings
  - Write batches
  - Snapshots
  - Iterators
  - Prefixed databases
  - Custom comparators
- API reference
  - Database
  - Write batch
  - Snapshot
  - Iterator
  - Errors
- Version history
  - Plyvel 1.0.2
  - Plyvel 1.0.1
  - Plyvel 1.0.0
  - Plyvel 0.9
  - Plyvel 0.8
  - Plyvel 0.7
  - Plyvel 0.6
  - Plyvel 0.5
  - Plyvel 0.4
  - Plyvel 0.3
  - Plyvel 0.2
  - Plyvel 0.1
- Contributing and developing
  - Reporting issues
  - Obtaining the source code
  - Compiling from source
  - Running the tests
  - Producing binary packages
  - Generating the documentation
- License

External links

- Online documentation (Read the docs)
- Project page with source code and issue tracker (Github)
- Python Package Index (PyPI) page with released tarballs